jj.majavat.parser


create-filter-mapclj

(create-filter-map dictionary json-serializer)
source

expand-macrosclj

(expand-macros parsed)

Second parse phase: takes the [ast macros] pair produced by parse and splices every :macro-call node into its expansion. An error map from phase one is passed through untouched. Returns the final node vector or an error map.

Second parse phase: takes the [ast macros] pair produced by `parse` and
splices every :macro-call node into its expansion. An error map from phase
one is passed through untouched. Returns the final node vector or an error map.
sourceraw docstring

parseclj

(parse resource-path
       template-resolver
       user-filters
       user-sanitizers
       dictionary
       current-sanitizer
       json-serializer)
source

parse-templateclj

(parse-template resource-path
                template-resolver
                user-filters
                user-sanitizers
                dictionary
                current-sanitizer
                json-serializer
                fragment)
source

resolve-pathclj

(resolve-path context path)
source

cljdoc builds & hosts documentation for Clojure/Script libraries