(expand-macros parsed)Second parse phase: takes the [ast macros] pair produced by parse and
splices every :macro-call node into its expansion. An error map from phase
one is passed through untouched. Returns the final node vector or an error map.
Second parse phase: takes the [ast macros] pair produced by `parse` and splices every :macro-call node into its expansion. An error map from phase one is passed through untouched. Returns the final node vector or an error map.
(parse resource-path
template-resolver
user-filters
user-sanitizers
dictionary
current-sanitizer
json-serializer)(parse-template resource-path
template-resolver
user-filters
user-sanitizers
dictionary
current-sanitizer
json-serializer
fragment)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |